cgexplore.molecular.PrecursorGenerator
======================================

.. currentmodule:: cgexplore.molecular

.. autoclass:: PrecursorGenerator
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PrecursorGenerator.get_building_block
      ~PrecursorGenerator.get_smiles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PrecursorGenerator.bead_distance
      ~PrecursorGenerator.composition
      ~PrecursorGenerator.present_beads
      ~PrecursorGenerator.binder_beads
      ~PrecursorGenerator.placer_beads
   
   